<?php

/**
 * Plugin Name: MyRewards Addon : Points for Coupon
 * Description: Adds an event to give points for using a coupon.
 * Plugin URI: https://plugins.longwatchstudio.com/product/woorewards/
 * Author: Long Watch Studio
 * Author URI: https://longwatchstudio.com/
 * Version: 1.1.1
 * License: Copyright LongWatchStudio 2022
 * Text Domain: woorewards-points-for-coupon
 * Domain Path: /languages
 *
 * Copyright (c) 2022 Long Watch Studio (email: contact@longwatchstudio.com). All rights reserved.
 *
 *
 */


// don't call the file directly
if (!defined('ABSPATH')) exit();

final class LWS_WooRewards_Points_For_Coupon
{
	public static function init()
	{
		static $instance = false;
		if (!$instance) {
			$instance = new self();
			$instance->defineConstants();
			$instance->load_plugin_textdomain();
			add_filter('lws-ap-release-woorewards-addon-points-for-coupon', function ($rc) {return ($rc . 'pro');});
			add_action('lws_adminpanel_plugins', array($instance, 'plugin'), 100); // priority after main license install
		}
		return $instance;
	}

	/**
	 * Define the plugin constants
	 *
	 * @return void
	 */
	private function defineConstants()
	{
		define('LWS_WOOREWARDS_POINTS_FOR_COUPON_FILE', __FILE__);

		define('LWS_WOOREWARDS_POINTS_FOR_COUPON_PATH', dirname(LWS_WOOREWARDS_POINTS_FOR_COUPON_FILE));
		define('LWS_WOOREWARDS_POINTS_FOR_COUPON_INCLUDES', LWS_WOOREWARDS_POINTS_FOR_COUPON_PATH . '/include');

		define('LWS_WOOREWARDS_POINTS_FOR_COUPON_URL', plugins_url('', LWS_WOOREWARDS_POINTS_FOR_COUPON_FILE));
		define('LWS_WOOREWARDS_POINTS_FOR_COUPON_IMG', plugins_url('/img', LWS_WOOREWARDS_POINTS_FOR_COUPON_FILE));
		define('LWS_WOOREWARDS_POINTS_FOR_COUPON_JS', plugins_url('/js', LWS_WOOREWARDS_POINTS_FOR_COUPON_FILE));
		define('LWS_WOOREWARDS_POINTS_FOR_COUPON_CSS', plugins_url('/css', LWS_WOOREWARDS_POINTS_FOR_COUPON_FILE));
		define('LWS_WOOREWARDS_POINTS_FOR_COUPON_DOMAIN', 'woorewards-points-for-coupon');
	}

	/** Load translation file
	 * If called via a hook like this
	 * @code
	 * add_action( 'plugins_loaded', array($instance,'load_plugin_textdomain'), 1 );
	 * @endcode
	 * Take care no text is translated before. */
	public function load_plugin_textdomain()
	{
		load_plugin_textdomain('woorewards-points-for-coupon', false, substr(dirname(__FILE__), strlen(WP_PLUGIN_DIR)) . '/languages/');
	}

	public function plugin()
	{
		if (defined('LWS_WOOREWARDS_ACTIVATED') && LWS_WOOREWARDS_ACTIVATED) {
			$minVers = '4.2.5';
			if (defined('LWS_WOOREWARDS_PRO_VERSION') && \version_compare(LWS_WOOREWARDS_PRO_VERSION, $minVers, '>=')) {
				$ret = \apply_filters('lws_manager_instance', false);
				if ($ret) {
					$ret->instance->register(__FILE__, 'woorewards', 'woorewards-addon-points-for-coupon');
				}
				\add_action('lws_woorewards_registration', function () {
					\LWS\WOOREWARDS\Abstracts\Event::register('\LWS\WOOREWARDS\Coupons\Events\UseCoupon', LWS_WOOREWARDS_POINTS_FOR_COUPON_INCLUDES . '/events/usecoupon.php');
				});
			} elseif (\is_admin()) {
				\lws_admin_add_notice_once('woorewards-points-for-coupon' . '-nolic', sprintf(
					__('The <i>%1$s</i> requires MyRewards Pro %2$s or higher. Please update the WooRewards plugin', 'woorewards-points-for-coupon'),
					\get_plugin_data(__FILE__, false)['Name'],
					$minVers
				), array('level' => 'warning'));
			}
		} elseif (\is_admin()) {
			\lws_admin_add_notice_once('woorewards-points-for-coupon' . '-nolic', sprintf(
				__('The <i>%s</i> requires WooRewards Pro with an activated license.', 'woorewards-points-for-coupon'),
				\get_plugin_data(__FILE__, false)['Name']
			), array('level' => 'warning'));
		}
	}
}

LWS_WooRewards_Points_For_Coupon::init();
